@@ -416,6 +416,23 @@ class Confluence(AtlassianRestAPI):
             data['ancestors'] = [{'type': type, 'id': parent_id}]
         return self.post(url, data=data)
 
+    def move_page(self, space_key, page_id, target_title, position="append"):
+        """
+        Move page method
+        :param space_key:
+        :param page_id:
+        :param target_title:
+        :param position: topLevel or append
+        :return:
+        """
+        url = "/pages/movepage.action"
+        params = {"spaceKey": space_key, "pageId": page_id}
+        if target_title:
+            params["targetTitle"] = target_title
+        if position:
+            params["position"] = position
+        return self.get(url, params=params, headers=self.no_check_headers)
+
     def get_all_spaces(self, start=0, limit=500, expand=None):
         """
         Get all spaces with provided limit
@@ -712,9 +729,14 @@ class Confluence(AtlassianRestAPI):
         :param title: Title to compare
         :return: True if the same
         """
-        confluence_content = (((self.get_page_by_id(page_id, expand='body.storage') or {})
-                               .get('body') or {})
-                              .get('storage') or {})
+        if self.advanced_mode:
+            confluence_content = (((self.get_page_by_id(page_id, expand='body.storage').json() or {})
+                                   .get('body') or {})
+                                  .get('storage') or {})
+        else:
+            confluence_content = (((self.get_page_by_id(page_id, expand='body.storage') or {})
+                                   .get('body') or {})
+                                  .get('storage') or {})
 
         if title:
             current_title = confluence_content.get('title', None)
@@ -731,7 +753,7 @@ class Confluence(AtlassianRestAPI):
         log.debug('Old Content: """{body}"""'.format(body=confluence_body_content))
         log.debug('New Content: """{body}"""'.format(body=body))
 
-        if confluence_body_content == body:
+        if confluence_body_content.strip() == body.strip():
             log.warning('Content of {page_id} is exactly the same'.format(page_id=page_id))
             return True
         else:
@@ -765,7 +787,10 @@ class Confluence(AtlassianRestAPI):
             return self.get_page_by_id(page_id)
         else:
             try:
-                version = self.history(page_id)['lastUpdated']['number'] + 1
+                if self.advanced_mode:
+                    version = self.history(page_id).json()['lastUpdated']['number'] + 1
+                else:
+                    version = self.history(page_id)['lastUpdated']['number'] + 1
             except (IndexError, TypeError) as e:
                 log.error("Can't find '{title}' {type}!".format(title=title, type=type))
                 log.debug(e)
@@ -785,8 +810,9 @@ class Confluence(AtlassianRestAPI):
 
             return self.put('rest/api/content/{0}'.format(page_id), data=data)
 
-    def _insert_to_existing_page(self, page_id, title, insert_body, parent_id=None, type='page', representation='storage',
-                    minor_edit=False, top_of_page=False):
+    def _insert_to_existing_page(self, page_id, title, insert_body, parent_id=None, type='page',
+                                 representation='storage',
+                                 minor_edit=False, top_of_page=False):
         """
         Insert body to a page if already exist
         :param parent_id:
@@ -841,11 +867,12 @@ class Confluence(AtlassianRestAPI):
         """
         log.info('Updating {type} "{title}"'.format(title=title, type=type))
 
-        return self._insert_to_existing_page(page_id, title, append_body, parent_id=parent_id, type=type, representation=representation,
-                    minor_edit=minor_edit, top_of_page=False)
+        return self._insert_to_existing_page(page_id, title, append_body, parent_id=parent_id, type=type,
+                                             representation=representation,
+                                             minor_edit=minor_edit, top_of_page=False)
 
     def prepend_page(self, page_id, title, prepend_body, parent_id=None, type='page', representation='storage',
-                    minor_edit=False):
+                     minor_edit=False):
         """
         Append body to page if already exist
         :param parent_id:
@@ -860,8 +887,9 @@ class Confluence(AtlassianRestAPI):
         """
         log.info('Updating {type} "{title}"'.format(title=title, type=type))
 
-        return self._insert_to_existing_page(page_id, title, prepend_body, parent_id=parent_id, type=type, representation=representation,
-                    minor_edit=minor_edit, top_of_page=True)
+        return self._insert_to_existing_page(page_id, title, prepend_body, parent_id=parent_id, type=type,
+                                             representation=representation,
+                                             minor_edit=minor_edit, top_of_page=True)
 
     def update_or_create(self, parent_id, title, body, representation='storage', minor_edit=False):
         """
@@ -1012,8 +1040,10 @@ class Confluence(AtlassianRestAPI):
         :param expand: OPTIONAL: additional info from description, homepage
         :return: Returns the space along with its ID
         """
-        url = 'rest/api/space/{space_key}?expand={expand}'.format(space_key=space_key,
-                                                                  expand=expand)
+        url = 'rest/api/space/{space_key}'.format(space_key=space_key)
+        params = {}
+        if expand:
+            params["expand"] = expand
         return self.get(url)
 
     def create_space(self, space_key, space_name):
@@ -1038,6 +1068,13 @@ class Confluence(AtlassianRestAPI):
         url = 'rest/api/space/{}'.format(space_key)
         return self.delete(url)
 
+    def get_space_property(self, space_key, expand=None):
+        url = 'rest/api/space/{space}/property'.format(space=space_key)
+        params = {}
+        if expand:
+            params['expand'] = expand
+        return self.get(url, params=params)
+
     def get_user_details_by_username(self, username, expand=None):
         """
         Get information about a user through username
